##  Scope
  * Supported fact sheet types:
    * From SAP LeanIX to Jira Service Management: Applications and their subtypes.
    * From Jira Service Management to SAP LeanIX: IT components and their subtypes.
  * Supported attribute types: Text fields.
  * Synchronization mode: Additive synchronization only (existing data is not deleted).
